SecretKey

Struct SecretKey 

pub struct SecretKey { /* private fields */ }
Secret key for the Eyvara VRF.

Secret vectors are private, are not cloneable through the public API, and are redacted in debug output. The key zeroizes its memory when dropped.

Implementations

Source

impl SecretKey

pub fn rho(&self) -> &[u8; 32]

Returns the public matrix seed. Safe to expose.

pub fn public_key(&self) -> &PublicKey

Returns the public key component corresponding to this secret key.

This does not expose the secret vectors s or e.